pub struct Svm { /* private fields */ }Implementations
Sourceimpl Svm
impl Svm
pub fn new(rpc_url: String) -> Self
pub async fn get_express_relay_metadata( &self, chain_id: String, ) -> Result<ExpressRelayMetadata, ClientError>
pub fn get_express_relay_pid(chain_id: String) -> Pubkey
pub fn get_submit_bid_instruction( params: GetSubmitBidInstructionParams, ) -> Result<Instruction, ClientError>
pub fn get_memo_instruction(memo: String) -> Instruction
pub fn get_swap_create_accounts_idempotent_instructions( params: GetSwapCreateAccountsIdempotentInstructionsParams, ) -> Vec<Instruction>
pub fn get_swap_instruction( params: GetSwapInstructionParams, ) -> Result<Instruction, ClientError>
pub fn get_wrap_sol_instructions( params: GetWrapSolInstructionsParams, ) -> Result<Vec<Instruction>, ClientError>
pub fn get_unwrap_sol_instruction( params: GetUnwrapSolInstructionParams, ) -> Result<Instruction, ClientError>
pub fn get_user_amount_to_wrap( amount_user: u64, user_mint_user_balance: u64, token_account_initialization_configs: &TokenAccountInitializationConfigs, ) -> u64
Sourcepub fn get_bid_amount_including_fees(
opportunity: &OpportunityParamsSvm,
bid_amount: u64,
) -> Result<u64, ClientError>
pub fn get_bid_amount_including_fees( opportunity: &OpportunityParamsSvm, bid_amount: u64, ) -> Result<u64, ClientError>
Adjusts the bid amount in the case where the amount that needs to be provided by the searcher is specified and the fees are in the user token.
In this case, searchers’ bids represent how many tokens they would like to receive.
However, for the searcher to receive bidAmount, the user needs to provide bidAmount * (FEE_SPLIT_PRECISION / (FEE_SPLIT_PRECISION - fees))
This function handles this adjustment.